using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;
using Components.Calendar.MonthCal.Class;

namespace Components.Calendar.MonthCal.Class.Event
{
    /// <summary>
    /// EventArgs of a MonthChanged
    /// </summary>
    public class MonthChangedEventArgs : EventArgs
    {
        #region Variables
        /// <summary>
        /// DateToDisplay before the event
        /// </summary>
        private DateTime vCurrentDate;
        /// <summary>
        /// DateToDisplay after the event
        /// </summary>
        private DateTime vNewDate;
        /// <summary>
        /// The clicked menu
        /// </summary>
        private ClickOnMenu vClickOnMenu = ClickOnMenu.Nothing;
        #endregion

        #region Constructeur
        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="_DateBeforeClick">DateToDisplay before the date change</param>
        /// <param name="_DateAfterClick">DateToDisplay after the date change</param>
        public MonthChangedEventArgs(DateTime _DateBeforeClick, DateTime _DateAfterClick)
        {
            vCurrentDate = _DateBeforeClick;
            vNewDate = _DateAfterClick;
            if (_DateBeforeClick > _DateAfterClick)
                vClickOnMenu = ClickOnMenu.PreviousMonth;
            else if (_DateBeforeClick < _DateAfterClick)
                vClickOnMenu = ClickOnMenu.NextMonth;
            else
                vClickOnMenu = ClickOnMenu.Nothing;
        }
        #endregion

        #region Accesseurs
        /// <summary>
        /// Gets the moonth before the month change
        /// </summary>
        public int MonthBeforeClick { get { return vCurrentDate.Month; } }
        /// <summary>
        /// Gets the year before the month change
        /// </summary>
        public int YearBeforeClick { get { return vCurrentDate.Year; } }
        /// <summary>
        /// Gets the date before the month change
        /// </summary>
        public DateTime DateBeforeClick { get { return vCurrentDate; } }
        /// <summary>
        /// Gets the month after the month change
        /// </summary>
        public int MonthAfterClick { get { return vNewDate.Month; } }
        /// <summary>
        /// Gets the year after the month change
        /// </summary>
        public int YearAfterClick { get { return vNewDate.Year; } }
        /// <summary>
        /// Gets the date after the month change
        /// </summary>
        public DateTime DateAfterClick { get { return vNewDate; } }
        /// <summary>
        /// Indicates which month navigation menu was clicked
        /// </summary>
        public ClickOnMenu MenuClicked { get { return vClickOnMenu; } }
        #endregion
    }
    /// <summary>
    /// Represents the method that will handle an MonthChanged event that has MonthChangedEventArgs data
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="args"></param>    
    [Serializable]
    [ComVisible(true)]
    public delegate void MonthChangedEventHandler(object sender, MonthChangedEventArgs args);
}
